==> pomodoro_v0.1_source.tar.bz2: pomodoro_v0.1_source/src/pomodoro.ml <==
(*
©  Clément Joly, 2016-2017

leo@wzukw.eu.org

This software is a computer program whose purpose is to use Pomodoro method.

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms.

*)

open Core.Std;;

let () =
  (* Get timers with command line arguments, mutable to allow easier update *)
  let log = ref (
      Sys.argv |> function
      | [| _ ; name |] -> Log_f.read_log name
      | _ -> failwith "Needs exactly one argument, filename of your log file."
    ) in
  (* Update log file *)
  (Lwt_engine.on_timer Param.log_tick true
     (fun _ ->
        log := Log_f.reread_log !log))
  |> ignore;

  Lwt_main.run (Views.mainv ~log ())
;;

==> pomodoro_v0.2_source.tar.bz2: pomodoro_v0.2_source/src/pomodoro.ml <==
(*
©  Clément Joly, 2016-2017

leo@wzukw.eu.org

This software is a computer program whose purpose is to use Pomodoro method.

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms.

*)

open Core.Std;;

let () =
  (* TODO Allow to configure this *)
  Unix.nice 19 |> ignore;

  (* Get timers with command line arguments, mutable to allow easier update *)
  let log =
    Sys.argv
    |> (function
        | [| _ ; name |] -> new Log_f.read_log name
        | _ -> failwith "Needs exactly one argument, filename of your log file.")
  in

  Lwt_main.run ( Views.mainv ~log () )
;;
